# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/assistant/embedded/v1alpha2/embedded_assistant.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;google/assistant/embedded/v1alpha2/embedded_assistant.proto\x12\"google.assistant.embedded.v1alpha2\"o\n\rAssistRequest\x12\x42\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x30.google.assistant.embedded.v1alpha2.AssistConfigH\x00\x12\x12\n\x08\x61udio_in\x18\x02 \x01(\x0cH\x00\x42\x06\n\x04type\"\xd4\x04\n\x0e\x41ssistResponse\x12P\n\nevent_type\x18\x01 \x01(\x0e\x32<.google.assistant.embedded.v1alpha2.AssistResponse.EventType\x12?\n\taudio_out\x18\x03 \x01(\x0b\x32,.google.assistant.embedded.v1alpha2.AudioOut\x12\x41\n\nscreen_out\x18\x04 \x01(\x0b\x32-.google.assistant.embedded.v1alpha2.ScreenOut\x12G\n\rdevice_action\x18\x06 \x01(\x0b\x32\x30.google.assistant.embedded.v1alpha2.DeviceAction\x12S\n\x0espeech_results\x18\x02 \x03(\x0b\x32;.google.assistant.embedded.v1alpha2.SpeechRecognitionResult\x12L\n\x10\x64ialog_state_out\x18\x05 \x01(\x0b\x32\x32.google.assistant.embedded.v1alpha2.DialogStateOut\x12\x41\n\ndebug_info\x18\x08 \x01(\x0b\x32-.google.assistant.embedded.v1alpha2.DebugInfo\"=\n\tEventType\x12\x1a\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x45ND_OF_UTTERANCE\x10\x01\"0\n\tDebugInfo\x12#\n\x1b\x61og_agent_to_assistant_json\x18\x01 \x01(\t\"\xf4\x03\n\x0c\x41ssistConfig\x12L\n\x0f\x61udio_in_config\x18\x01 \x01(\x0b\x32\x31.google.assistant.embedded.v1alpha2.AudioInConfigH\x00\x12\x14\n\ntext_query\x18\x06 \x01(\tH\x00\x12L\n\x10\x61udio_out_config\x18\x02 \x01(\x0b\x32\x32.google.assistant.embedded.v1alpha2.AudioOutConfig\x12N\n\x11screen_out_config\x18\x08 \x01(\x0b\x32\x33.google.assistant.embedded.v1alpha2.ScreenOutConfig\x12J\n\x0f\x64ialog_state_in\x18\x03 \x01(\x0b\x32\x31.google.assistant.embedded.v1alpha2.DialogStateIn\x12G\n\rdevice_config\x18\x04 \x01(\x0b\x32\x30.google.assistant.embedded.v1alpha2.DeviceConfig\x12\x45\n\x0c\x64\x65\x62ug_config\x18\x05 \x01(\x0b\x32/.google.assistant.embedded.v1alpha2.DebugConfigB\x06\n\x04type\"\xb6\x01\n\rAudioInConfig\x12L\n\x08\x65ncoding\x18\x01 \x01(\x0e\x32:.google.assistant.embedded.v1alpha2.AudioInConfig.Encoding\x12\x19\n\x11sample_rate_hertz\x18\x02 \x01(\x05\"<\n\x08\x45ncoding\x12\x18\n\x14\x45NCODING_UNSPECIFIED\x10\x00\x12\x0c\n\x08LINEAR16\x10\x01\x12\x08\n\x04\x46LAC\x10\x02\"\xe3\x01\n\x0e\x41udioOutConfig\x12M\n\x08\x65ncoding\x18\x01 \x01(\x0e\x32;.google.assistant.embedded.v1alpha2.AudioOutConfig.Encoding\x12\x19\n\x11sample_rate_hertz\x18\x02 \x01(\x05\x12\x19\n\x11volume_percentage\x18\x03 \x01(\x05\"L\n\x08\x45ncoding\x12\x18\n\x14\x45NCODING_UNSPECIFIED\x10\x00\x12\x0c\n\x08LINEAR16\x10\x01\x12\x07\n\x03MP3\x10\x02\x12\x0f\n\x0bOPUS_IN_OGG\x10\x03\"\xa7\x01\n\x0fScreenOutConfig\x12S\n\x0bscreen_mode\x18\x01 \x01(\x0e\x32>.google.assistant.embedded.v1alpha2.ScreenOutConfig.ScreenMode\"?\n\nScreenMode\x12\x1b\n\x17SCREEN_MODE_UNSPECIFIED\x10\x00\x12\x07\n\x03OFF\x10\x01\x12\x0b\n\x07PLAYING\x10\x03\"\xac\x01\n\rDialogStateIn\x12\x1a\n\x12\x63onversation_state\x18\x01 \x01(\x0c\x12\x15\n\rlanguage_code\x18\x02 \x01(\t\x12K\n\x0f\x64\x65vice_location\x18\x05 \x01(\x0b\x32\x32.google.assistant.embedded.v1alpha2.DeviceLocation\x12\x1b\n\x13is_new_conversation\x18\x07 \x01(\x08\":\n\x0c\x44\x65viceConfig\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x17\n\x0f\x64\x65vice_model_id\x18\x03 \x01(\t\"\x1e\n\x08\x41udioOut\x12\x12\n\naudio_data\x18\x01 \x01(\x0c\"\x8b\x01\n\tScreenOut\x12\x44\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\x34.google.assistant.embedded.v1alpha2.ScreenOut.Format\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"*\n\x06\x46ormat\x12\x16\n\x12\x46ORMAT_UNSPECIFIED\x10\x00\x12\x08\n\x04HTML\x10\x01\"+\n\x0c\x44\x65viceAction\x12\x1b\n\x13\x64\x65vice_request_json\x18\x01 \x01(\t\"@\n\x17SpeechRecognitionResult\x12\x12\n\ntranscript\x18\x01 \x01(\t\x12\x11\n\tstability\x18\x02 \x01(\x02\"\xa5\x02\n\x0e\x44ialogStateOut\x12!\n\x19supplemental_display_text\x18\x01 \x01(\t\x12\x1a\n\x12\x63onversation_state\x18\x02 \x01(\x0c\x12Z\n\x0fmicrophone_mode\x18\x03 \x01(\x0e\x32\x41.google.assistant.embedded.v1alpha2.DialogStateOut.MicrophoneMode\x12\x19\n\x11volume_percentage\x18\x04 \x01(\x05\"]\n\x0eMicrophoneMode\x12\x1f\n\x1bMICROPHONE_MODE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x43LOSE_MICROPHONE\x10\x01\x12\x14\n\x10\x44IALOG_FOLLOW_ON\x10\x02\"(\n\x0b\x44\x65\x62ugConfig\x12\x19\n\x11return_debug_info\x18\x06 \x01(\x08\"\x10\n\x0e\x44\x65viceLocation2\x88\x01\n\x11\x45mbeddedAssistant\x12s\n\x06\x41ssist\x12\x31.google.assistant.embedded.v1alpha2.AssistRequest\x1a\x32.google.assistant.embedded.v1alpha2.AssistResponse(\x01\x30\x01\x42\x8f\x01\n&com.google.assistant.embedded.v1alpha2B\x0e\x41ssistantProtoP\x01ZJgoogle.golang.org/genproto/googleapis/assistant/embedded/v1alpha2;embedded\xa2\x02\x06\x41STSDKb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.assistant.embedded.v1alpha2.embedded_assistant_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.google.assistant.embedded.v1alpha2B\016AssistantProtoP\001ZJgoogle.golang.org/genproto/googleapis/assistant/embedded/v1alpha2;embedded\242\002\006ASTSDK'
  _ASSISTREQUEST._serialized_start=99
  _ASSISTREQUEST._serialized_end=210
  _ASSISTRESPONSE._serialized_start=213
  _ASSISTRESPONSE._serialized_end=809
  _ASSISTRESPONSE_EVENTTYPE._serialized_start=748
  _ASSISTRESPONSE_EVENTTYPE._serialized_end=809
  _DEBUGINFO._serialized_start=811
  _DEBUGINFO._serialized_end=859
  _ASSISTCONFIG._serialized_start=862
  _ASSISTCONFIG._serialized_end=1362
  _AUDIOINCONFIG._serialized_start=1365
  _AUDIOINCONFIG._serialized_end=1547
  _AUDIOINCONFIG_ENCODING._serialized_start=1487
  _AUDIOINCONFIG_ENCODING._serialized_end=1547
  _AUDIOOUTCONFIG._serialized_start=1550
  _AUDIOOUTCONFIG._serialized_end=1777
  _AUDIOOUTCONFIG_ENCODING._serialized_start=1701
  _AUDIOOUTCONFIG_ENCODING._serialized_end=1777
  _SCREENOUTCONFIG._serialized_start=1780
  _SCREENOUTCONFIG._serialized_end=1947
  _SCREENOUTCONFIG_SCREENMODE._serialized_start=1884
  _SCREENOUTCONFIG_SCREENMODE._serialized_end=1947
  _DIALOGSTATEIN._serialized_start=1950
  _DIALOGSTATEIN._serialized_end=2122
  _DEVICECONFIG._serialized_start=2124
  _DEVICECONFIG._serialized_end=2182
  _AUDIOOUT._serialized_start=2184
  _AUDIOOUT._serialized_end=2214
  _SCREENOUT._serialized_start=2217
  _SCREENOUT._serialized_end=2356
  _SCREENOUT_FORMAT._serialized_start=2314
  _SCREENOUT_FORMAT._serialized_end=2356
  _DEVICEACTION._serialized_start=2358
  _DEVICEACTION._serialized_end=2401
  _SPEECHRECOGNITIONRESULT._serialized_start=2403
  _SPEECHRECOGNITIONRESULT._serialized_end=2467
  _DIALOGSTATEOUT._serialized_start=2470
  _DIALOGSTATEOUT._serialized_end=2763
  _DIALOGSTATEOUT_MICROPHONEMODE._serialized_start=2670
  _DIALOGSTATEOUT_MICROPHONEMODE._serialized_end=2763
  _DEBUGCONFIG._serialized_start=2765
  _DEBUGCONFIG._serialized_end=2805
  _DEVICELOCATION._serialized_start=2807
  _DEVICELOCATION._serialized_end=2823
  _EMBEDDEDASSISTANT._serialized_start=2826
  _EMBEDDEDASSISTANT._serialized_end=2962
# @@protoc_insertion_point(module_scope)
